include_recipe 'git'

username = node['buildkite']['agent']['user']

group username

user username do
  group username
  manage_home true
  home "/home/#{username}"
  action :create

  notifies :create, "directory[/home/#{username}/.ssh]"
end

directory "/home/#{username}/.ssh" do
  owner username
  group username
  mode '0600'
end

file "/home/#{username}/.ssh/id_rsa" do
  owner username
  mode '0600'
  content Chef::EncryptedDataBagItem.load('deploy_keys', 'buildkite')['private']
end

bash 'add source' do
  code "sudo sh -c 'echo deb https://apt.buildkite.com/buildkite-agent stable main > /etc/apt/sources.list.d/buildkite-agent.list'"
end

bash 'add key' do
  code "sudo apt-key adv --keyserver hkp://keyserver.ubuntu.com:80 --recv-keys 32A37959C2FA5C3C99EFBC32A79206696452D198"
end

apt_update 'update apt' do
  action :update
  ignore_failure true

  notifies :install, 'apt_package[buildkite-agent]'
end

apt_package 'buildkite-agent'

template "#{node['buildkite']['agent']['path']}/buildkite-agent.cfg" do
  source 'default/buildkite-agent.cfg.erb'

  owner username
  group username
  mode '0400'

  variables({
    token: Chef::EncryptedDataBagItem.load('credentials', 'buildkite')['token'],
    debug: node['buildkite']['agent']['debug'],
    bootstrap: node['buildkite']['agent']['bootstrap']
  })

  notifies :restart, 'service[buildkite-agent]'
end

service 'buildkite-agent' do
  action :enable
end